@@ -35,24 +35,28 @@ class ColorChanger:
 
     def update_left_objects(self, current_color):
         for obj in self.skeleton.get_left_objects():
-            obj.color = int(current_color.new.replace('#', '0x'), 16)
+            obj.color = self.__get_as_hex_int(current_color.new)
 
     def update_right_objects(self, current_color):
         for obj in self.skeleton.get_right_objects():
-            obj.color = int(current_color.new.replace('#', '0x'), 16)
+            obj.color = self.__get_as_hex_int(current_color.new)
 
     def update_center_objects(self, current_color):
         for obj in self.skeleton.get_center_objects():
-            obj.color = int(current_color.new.replace('#', '0x'), 16)
+            obj.color = self.__get_as_hex_int(current_color.new)
 
     def update_all_objects(self, current_color):
         new_color = current_color.new
         for obj in self.skeleton:
-            obj.color = int(current_color.new.replace('#', '0x'), 16)
+            obj.color = self.__get_as_hex_int(new_color)
         self.left_color_picker.value = new_color
         self.right_color_picker.value = new_color
         self.center_color_picker.value = new_color
 
+    @staticmethod
+    def __get_as_hex_int(color: str):
+        return int(color.replace('#', '0x'), 16)
+
 
 class SkeletonVisualizer:
     """ A 3D skeleton visualizer which can visualize skeletons in 3D plots."""
@@ -216,10 +220,10 @@ class SkeletonVisualizer:
         children: List[VBox] = []
         for skeleton in self.skeletons:
             left_color_picker: ColorPicker = ColorPicker(
-                description='Left side color:',
+                description='Left color:',
                 value=self.__get_as_html_color(skeleton.get_left_objects()[0].color))
             right_color_picker: ColorPicker = ColorPicker(
-                description='Right side color:',
+                description='Right color:',
                 value=self.__get_as_html_color(skeleton.get_right_objects()[0].color))
             center_color_picker: ColorPicker = ColorPicker(
                 description='Center color:',
@@ -234,7 +238,7 @@ class SkeletonVisualizer:
             children.append(VBox([left_color_picker, right_color_picker, center_color_picker, all_color_picker]))
         color_changer_widget: Tab = Tab(children=children)
         for i in range(len(self.skeletons)):
-            color_changer_widget.set_title(i, 'Skeleton {:d} colors'.format(i))
+            color_changer_widget.set_title(i, 'Skeleton {:d} colors'.format(i + 1))
         display(color_changer_widget)
 
     @staticmethod
